@@ -533,15 +533,19 @@ Convenient to use with `cl-multiple-value-bind'"
 
 (defvar gptel-bedrock--model-ids
   ;; https://docs.aws.amazon.com/bedrock/latest/userguide/models-supported.html
-  '((claude-sonnet-4-20250514    . "anthropic.claude-sonnet-4-20250514-v1:0")
+  '((claude-sonnet-4-5-20250929  . "anthropic.claude-sonnet-4-5-20250929-v1:0")
+    (claude-haiku-4-5-20251001   . "anthropic.claude-haiku-4-5-20251001-v1:0")
+	(claude-opus-4-5-20251101    . "anthropic.claude-opus-4-5-20251101-v1:0")
+    (claude-opus-4-1-20250805    . "anthropic.claude-opus-4-1-20250805-v1:0")
+    (claude-sonnet-4-20250514    . "anthropic.claude-sonnet-4-20250514-v1:0")
     (claude-opus-4-20250514      . "anthropic.claude-opus-4-20250514-v1:0")
     (claude-3-7-sonnet-20250219  . "anthropic.claude-3-7-sonnet-20250219-v1:0")
     (claude-3-5-sonnet-20241022  . "anthropic.claude-3-5-sonnet-20241022-v2:0")
     (claude-3-5-sonnet-20240620  . "anthropic.claude-3-5-sonnet-20240620-v1:0")
     (claude-3-5-haiku-20241022   . "anthropic.claude-3-5-haiku-20241022-v1:0")
     (claude-3-opus-20240229      . "anthropic.claude-3-opus-20240229-v1:0")
-    (claude-3-sonnet-20240229    . "anthropic.claude-3-sonnet-20240229-v1:0")
     (claude-3-haiku-20240307     . "anthropic.claude-3-haiku-20240307-v1:0")
+    (nova-2-lite-v1              . "amazon.nova-2-lite-v1:0")
     (mistral-7b                  . "mistral.mistral-7b-instruct-v0:2")
     (mistral-8x7b                . "mistral.mixtral-8x7b-instruct-v0:1")
     (mistral-large-2402          . "mistral.mistral-large-2402-v1:0")
@@ -569,10 +573,10 @@ IDs can be added or replaced by calling
 (defun gptel-bedrock--get-model-id (model &optional region)
   "Return the Bedrock model ID for MODEL.
 
-REGION is one of apac, eu or us."
+REGION is one of global, apac, eu or us."
   (concat
    (when region
-     (or (member region '(apac eu us))
+     (or (member region '(global apac eu us))
 	 (error "Unknown Bedrock region %s" region))
      (concat (symbol-name region) "."))
    (or (alist-get model gptel-bedrock--model-ids nil nil #'eq)
