@@ -77,7 +77,7 @@
      :description "The best model for coding and agentic tasks"
      :capabilities (media tool-use json url)
      :mime-types ("image/jpeg" "image/png" "image/gif" "image/webp")
-     :context-window 264
+     :context-window 400
      :input-cost 1
      :output-cost 1
      :cutoff-date "2024-09")
@@ -85,7 +85,15 @@
      :description "The best model for coding and agentic tasks"
      :capabilities (media tool-use json url)
      :mime-types ("image/jpeg" "image/png" "image/gif" "image/webp")
-     :context-window 264
+     :context-window 400
+     :input-cost 1
+     :output-cost 1
+     :cutoff-date "2025-08")
+    (gpt-5.2-codex
+     :description "The best model for coding and agentic tasks"
+     :capabilities (media tool-use json url)
+     :mime-types ("image/jpeg" "image/png" "image/gif" "image/webp")
+     :context-window 400
      :input-cost 1
      :output-cost 1
      :cutoff-date "2025-08")
@@ -129,6 +137,14 @@
      :input-cost 3
      :output-cost 3
      :cutoff-date "2025-05")
+    (claude-opus-4.6
+     :description "Most capable model for complex reasoning and advanced coding"
+     :capabilities (media tool-use cache)
+     :mime-types ("image/jpeg" "image/png" "image/gif" "image/webp" "application/pdf")
+     :context-window 200
+     :input-cost 3
+     :output-cost 3
+     :cutoff-date "2025-08")
     (gemini-2.5-pro
      :description "Next gen, high speed, multimodal for a diverse variety of tasks"
      :capabilities (tool-use json media)
